@@ -34,6 +34,7 @@ class SpellBot(Bot):
         intents = discord.Intents().default()
         intents.members = True  # pylint: disable=E0237
         intents.message_content = True  # pylint: disable=E0237
+        logger.info(f"{intents.value=}")
         super().__init__(
             command_prefix="!",
             help_command=None,
@@ -44,6 +45,10 @@ class SpellBot(Bot):
         self.mock_games = mock_games
         self.create_connection = create_connection
         self.channel_locks = ExpiringDict(max_len=100, max_age_seconds=3600)  # 1 hr
+        self.event
+
+    async def on_ready(self):
+        logger.info("client ready")
 
     async def setup_hook(self) -> None:
         # Note: In tests we create the connection using fixtures.
@@ -51,7 +56,7 @@ class SpellBot(Bot):
             logger.info("initializing database connection...")
             await initialize_connection("spellbot-bot")
 
-        # register persistant views
+        # register persistent views
         from .views import PendingGameView, SetupView, StartedGameView
 
         self.add_view(PendingGameView(self))
