@@ -12,6 +12,15 @@ logger = logging.getLogger(__name__)
 settings = Settings()
 
 
+async def wait_until_ready(bot: SpellBot) -> None:
+    while True:
+        try:
+            await bot.wait_until_ready()
+            break
+        except BaseException as e:  # Catch EVERYTHING so tasks don't die
+            logger.exception("error: exception in task before loop: %s", e)
+
+
 class TasksCog(commands.Cog):  # pragma: no cover
     def __init__(self, bot: SpellBot):
         self.bot = bot
@@ -21,23 +30,29 @@ class TasksCog(commands.Cog):  # pragma: no cover
 
     @tasks.loop(minutes=settings.VOICE_CLEANUP_LOOP_M)
     async def cleanup_old_voice_channels(self):
-        with tracer.trace(name="command", resource="cleanup_old_voice_channels"):
-            async with TasksAction.create(self.bot) as interaction:
-                await interaction.cleanup_old_voice_channels()
+        try:
+            with tracer.trace(name="command", resource="cleanup_old_voice_channels"):
+                async with TasksAction.create(self.bot) as interaction:
+                    await interaction.cleanup_old_voice_channels()
+        except BaseException as e:  # Catch EVERYTHING so tasks don't die
+            logger.exception("error: exception in task cog: %s", e)
 
     @cleanup_old_voice_channels.before_loop
     async def before_cleanup_old_voice_channels(self):
-        await self.bot.wait_until_ready()
+        await wait_until_ready(self.bot)
 
     @tasks.loop(minutes=settings.EXPIRE_GAMES_LOOP_M)
     async def expire_inactive_games(self):
-        with tracer.trace(name="command", resource="expire_inactive_games"):
-            async with TasksAction.create(self.bot) as interaction:
-                await interaction.expire_inactive_games()
+        try:
+            with tracer.trace(name="command", resource="expire_inactive_games"):
+                async with TasksAction.create(self.bot) as interaction:
+                    await interaction.expire_inactive_games()
+        except BaseException as e:  # Catch EVERYTHING so tasks don't die
+            logger.exception("error: exception in task cog: %s", e)
 
     @expire_inactive_games.before_loop
     async def before_expire_inactive_games(self):
-        await self.bot.wait_until_ready()
+        await wait_until_ready(self.bot)
 
 
 async def setup(bot: SpellBot):  # pragma: no cover
